@@ -77,20 +77,22 @@ def watch(fns=None, path=None, files=None, run_immediately=True,
     if files:
         normalize_files_dict(files, path)
 
-    if not predicate:
-        def predicate(event, watcher):
-            if not watcher.files:
-                return True
-            files = get_files(watcher.files)
+    def predikate(event, watcher):
+        if predicate and not predicate(event, watcher):
+            return False
 
-            found = getattr(event, 'dest_path', None) in files
-            return found or event.src_path in files
+        if not watcher.files:
+            return True
+        files = get_files(watcher.files)
+
+        found = getattr(event, 'dest_path', None) in files
+        return found or event.src_path in files
 
     handler = handler or WatchHandler(fns,
                                       throttle=throttle,
                                       files=files,
                                       callback=callback,
-                                      predicate=predicate)
+                                      predicate=predikate)
 
     observer = PollingObserver(timeout=poll_timeout) if poll_timeout else Observer()
     observer.schedule(handler, path=path, recursive=recursive)
